#############################################################################
# Author:                                                                   #
# ------                                                                    #
#  Anton Kokalj                                  Email: Tone.Kokalj@ijs.si  #
#  Department of Physical and Organic Chemistry  Phone: x 386 1 477 3523    #
#  Jozef Stefan Institute                          Fax: x 386 1 477 3811    #
#  Jamova 39, SI-1000 Ljubljana                                             #
#  SLOVENIA                                                                 #
#                                                                           #
# Source: $XCRYSDEN_TOPDIR/Tcl/forces.tcl
# ------                                                                    #
# Copyright (c) 1996-2003 by Anton Kokalj                                   #
#############################################################################

proc forceVectors can {
    global check sInfo
    
    if { ! [info exists sInfo(lforce)] } {
	return
    }
    if { ! $sInfo(lforce) } {
	return
    }

    if { $check(forces) } {
	xc_forces $can on
	$can render
	xcSwapBuffers
    } else {
	xc_forces $can off
	$can render
	xcSwapBuffers
    }
}

proc forceVectorsSet can {
    global check forceVec sInfo

    if { ! [info exists sInfo(lforce)] } {
	return
    }
    
    set c [lindex [split $can .] end]
    if { [winfo exists .force$c] } {
	return
    }

    if { ![info exists forceVec(scalefunction)] } {
	set forceVec(scalefunction) linear
	set forceVec(threshold)     0.0005
	set forceVec(lengthfactor)  100
    }

    # from here on: widget managing
    set t [xcToplevel .force$c "Forces: Settings" "Forces" . -0 0 1]
    set f1 [frame $t.f1]
    set f2 [frame $t.f2]
    pack $f1 $f2 -side top -expand 1 -padx 3m -pady 3m

    set mb [xcMenuButton $f1 \
	    -labeltext  "Scale Function:" \
	    -labelwidth 15 \
	    -textvariable forceVec(scalefunction) \
	    -menu { \
	    {Linear}             {set forceVec(scalefunction) linear} \
	    {Natural Logarithm}  {set forceVec(scalefunction) log} \
	    {Decadic Logaritm}   {set forceVec(scalefunction) log10} \
	    {Square Root}        {set forceVec(scalefunction) sqrt} \
	    {Cubic  Root}        {set forceVec(scalefunction) root3} \
	    {Exponential}        {set forceVec(scalefunction) exp} \
	    {exp(x*x)}           {set forceVec(scalefunction) exp2} \
	}]

    set m1 [message $f1.m1 -justify left -aspect 800 \
	    -text "Threshold::\ndo not show the forces whose magnitude is smaller then the specified threshold.\n\n\nLength Factor::\nassumed unit for force is Hartree/Angstrom\nforceVector_length == forceVectorSize * LengthFactor"]
    pack $mb $m1 -side top -fill x -anchor w -expand 1
    FillEntries $f1 {Treshold {Length Factor}} \
	    {forceVec(threshold) forceVec(lengthfactor)} 13 10 top left

    set b1 [button $f2.close -text "Close" -command [list DestroyWid $t]]
    set b2 [button $f2.update -text "Update" \
	    -command [list forceUpdate $can]]
    
    pack $b1 $b2 -side left -padx 3m -pady 3m -expand 1
}

proc forceUpdate can {
    global forceVec
    
    xc_forces $can scalefunction  $forceVec(scalefunction)
    xc_forces $can threshold      $forceVec(threshold)
    xc_forces $can lengthfactor   $forceVec(lengthfactor)
    $can render
    xcSwapBuffers
}