#############################################################################
# Author:                                                                   #
# ------                                                                    #
#  Anton Kokalj                                  Email: Tone.Kokalj@ijs.si  #
#  Department of Physical and Organic Chemistry  Phone: x 386 1 477 3523    #
#  Jozef Stefan Institute                          Fax: x 386 1 477 3811    #
#  Jamova 39, SI-1000 Ljubljana                                             #
#  SLOVENIA                                                                 #
#                                                                           #
# Source: $XCRYSDEN_TOPDIR/Tcl/genFSInit.tcl
# ------                                                                    #
# Copyright (c) 1996-2003 by Anton Kokalj                                   #
#############################################################################

proc genFSInit {file} {
    global wn fs xcMisc system

    set file [gunzipXSF $file]

    #
    # lets read (band)XSF file; xc_readband return info structure which look
    # like:
    #
    # 1 { grid_index 3D grid_ident grid_nband 1 {subgrid0_ident}}
    set spin {}
    
    #
    # we must construct normal XSF file out of BXSF file and
    # run fsREadBXSF program to construct lattice vectors and Brillouin zone
    #
    if [catch {exec $system(BINDIR)/fsReadBXSF $file \
	    $system(SCRDIR)/bxsf2xsf.xsf}] {
	tk_dialog [WidgetName] ERROR "ERROR: an error occured while executing fsReadBXSF program" error 0 OK
	exit
    }
    xc_readXSF $system(SCRDIR)/bxsf2xsf.xsf

    #
    # now read the BXSF file
    #
    set fs(titlefile) $file
    set sinfo [xc_readbandXSF $file]
    xcDebug -debug "DEBUG: FS-sinfo: $sinfo"
    # parse $sinfo
    set slist [lindex $sinfo 1]
    set fs($spin,nbands)        [lindex $slist 3]
    set fs($spin,grid_index)    [lindex $slist 0]
    set fs($spin,grid_subindex) [expr [lindex $slist 4] - 1]
 
    if ![info exists fs(Efermi)] {
	# read the Fermi level from BXSF file if it exists,
	# otherwise set it to zero
	set fs(Efermi) [FSGetFermiEnergy $file]
    }

    #
    # now set also MIN & MAX values of the band-grids
    #
    for {set i 1} {$i <= $fs($spin,nbands)} {incr i} {
	set fs($spin,$i,band_selected) 1
	set fs($spin,$i,minE) \
		[xc_gridvalue min $fs($spin,grid_index) [expr $i - 1]]
	set fs($spin,$i,maxE) \
		[xc_gridvalue max $fs($spin,grid_index) [expr $i - 1]]
	set fs($spin,$i,isolevel) $fs(Efermi)    
    }

    XCRYSDEN_Logo $file
    if [winfo exists .title] { 
	destroy .title 
    }

    FS_GoFermi $spin
}


proc FSGetFermiEnergy {file} {

    set fID [open $file r]

    set fermi     0
    set not_found 1
    while { $not_found } {
	set line [gets $fID]
	if [string match *FERMI*ENERGY* [string toupper $line]] {
	    set fermi [lindex $line end]
	    set not_found 0
	}
    }
    close $fID
    xcDebug -stderr "FermiEnergy: $fermi"
    if ![string is double $fermi] {
	set fermi 0
    }
    return $fermi
}

